@@ -1,5 +1,5 @@
 """
-Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - October 22, 2021
+Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - October 26, 2021
 """
 
 import time
@@ -111,7 +111,7 @@ def GenerationOperationModelFormulation(OptModel, mTEPES, pIndLogConsole, st):
     setattr(OptModel, 'eSystemInertia_'+st, Constraint(mTEPES.sc, mTEPES.p, mTEPES.n, mTEPES.ar, rule=eSystemInertia, doc='system inertia [s]'))
 
     if pIndLogConsole == 1:
-        print('eSystemInertia           ... ', len(getattr(OptModel, 'eSystemInertia_'+st)), ' rows')
+        print('eSystemInertia        ... ', len(getattr(OptModel, 'eSystemInertia_'+st)), ' rows')
 
     #%%
     def eOperReserveUp(OptModel,sc,p,n,ar):
@@ -337,6 +337,16 @@ def GenerationOperationModelFormulation(OptModel, mTEPES, pIndLogConsole, st):
     if pIndLogConsole == 1:
         print('eMaxCommitment        ... ', len(getattr(OptModel, 'eMaxCommitment_'+st)), ' rows')
 
+    def eMaxCommitESS(OptModel,sc,p,n,es):
+        if sum(1 for g in mTEPES.es if (es,g) in mTEPES.g2g or (g,es) in mTEPES.g2g) and mTEPES.pMaxPower[sc,p,n,es]:
+            return OptModel.vTotalOutput[sc,p,n,es]/mTEPES.pMaxPower[sc,p,n,es] <= OptModel.vMaxCommitment[es]
+        else:
+            return Constraint.Skip
+    setattr(OptModel, 'eMaxCommitESS_'+st, Constraint(mTEPES.sc, mTEPES.p, mTEPES.n, mTEPES.es, rule=eMaxCommitESS, doc='maximum of all the ESS per unit outputs'))
+
+    if pIndLogConsole == 1:
+        print('eMaxCommitESS         ... ', len(getattr(OptModel, 'eMaxCommitESS_'+st)), ' rows')
+
     def eExclusiveGens(OptModel,nr):
         if sum(1 for g in mTEPES.nr if (nr,g) in mTEPES.g2g):
             return OptModel.vMaxCommitment[nr] + sum(OptModel.vMaxCommitment[g] for g in mTEPES.nr if (nr,g) in mTEPES.g2g) <= 1
